@@ -1,10 +1,10 @@
 #' Download a congressional districts shapefile for the 114th Congress into R
 #'
 #' Description from the US Census Bureau (see link for source):
-#' The 2015 TIGER/Line Shapefiles contain the 114th Congressional Districts. All congressional districts
-#' appearing in the 2015 TIGER/Line Shapefiles reflect the information provided to the Census Bureau by
-#' the states by May 1, 2014. The 114th Congressional District shapefile contains the areas in effect
-#' January 2015 to 2017.
+#' The 2017 TIGER/Line Shapefiles contain the 115th Congressional Districts. All congressional districts
+#' appearing in the 2017 TIGER/Line Shapefiles reflect the information provided to the Census Bureau by
+#' the states by May 1, 2016. The 115th Congressional District shapefile contains the areas in effect from
+#' January 2017 to 2019.
 #'
 #' Congressional districts are the 435 areas from which people are elected to the U.S. House of
 #' Representatives and the five areas with nonvoting delegates from state equivalents. After the
@@ -18,12 +18,13 @@
 #'        TIGER/Line file).
 #' @param resolution The resolution of the cartographic boundary file (if cb == TRUE).
 #'        Defaults to '500k'; options include '5m' (1:5 million) and '20m' (1:20 million).
-#' @param year the data year (defaults to 2016).  To get boundaries for the 115th congress, set \code{year = 2016}.
+#' @param year the data year (defaults to 2017).  To get boundaries for the 115th congress, set \code{year = 2017}.
 #' @param ... arguments to be passed to the underlying `load_tiger` function, which is not exported.
-#'        Options include \code{refresh}, which specifies whether or not to re-download shapefiles
-#'        (defaults to \code{FALSE}).
+#'        Options include \code{class}, which can be set to \code{"sp"} (the default) or \code{"sf"} to
+#'        request sp or sf class objects, and \code{refresh}, which specifies whether
+#'        or not to re-download shapefiles (defaults to \code{FALSE}).
 #' @family legislative district functions
-#' @seealso \url{http://www2.census.gov/geo/pdfs/maps-data/data/tiger/tgrshp2015/TGRSHP2015_TechDoc.pdf}
+#' @seealso \url{http://www2.census.gov/geo/pdfs/maps-data/data/tiger/tgrshp2017/TGRSHP2017_TechDoc.pdf}
 #' @export
 #' @examples \dontrun{
 #' library(tigris)
@@ -39,11 +40,13 @@ congressional_districts <- function(cb = FALSE, resolution = '500k', year = NULL
 
   if (is.null(year)) {
 
-    year <- getOption("tigris_year", 2016)
+    year <- getOption("tigris_year", 2017)
 
   }
 
-  if (year == 2016) {
+  if (year == 2018) {
+    congress <- "116"
+  } else if (year %in% 2016:2017) {
     congress <- "115"
   } else if (year %in% 2014:2015) {
     congress <- "114"
@@ -103,10 +106,11 @@ congressional_districts <- function(cb = FALSE, resolution = '500k', year = NULL
 #' @param cb If cb is set to TRUE, download a generalized (1:500k)
 #'        cartographic boundary file.  Defaults to FALSE (the most detailed
 #'        TIGER/Line file).
-#' @param year the data year (defaults to 2016).
+#' @param year the data year (defaults to 2017).
 #' @param ... arguments to be passed to the underlying `load_tiger` function, which is not exported.
-#'        Options include \code{refresh}, which specifies whether or not to re-download shapefiles
-#'        (defaults to \code{FALSE}).
+#'        Options include \code{class}, which can be set to \code{"sp"} (the default) or \code{"sf"} to
+#'        request sp or sf class objects, and code{refresh}, which specifies whether or not to re-download
+#'        shapefiles (defaults to \code{FALSE}).
 #' @family legislative district functions
 #' @export
 #' @examples \dontrun{
@@ -125,7 +129,7 @@ state_legislative_districts <- function(state, house = "upper", cb = FALSE, year
 
   if (is.null(year)) {
 
-    year <- getOption("tigris_year", 2016)
+    year <- getOption("tigris_year", 2017)
 
   }
 
@@ -210,8 +214,9 @@ state_legislative_districts <- function(state, house = "upper", cb = FALSE, year
 #' @param state The state for which you'd like to retrieve data.  Can be a state name,
 #'        state abbreviation, or FIPS code.
 #' @param ... arguments to be passed to the underlying `load_tiger` function, which is not exported.
-#'        Options include \code{refresh}, which specifies whether or not to re-download shapefiles
-#'        (defaults to \code{FALSE}).
+#'        Options include \code{class}, which can be set to \code{"sp"} (the default) or \code{"sf"} to
+#'        request sp or sf class objects, and \code{refresh}, which specifies whether or not
+#'        to re-download shapefiles (defaults to \code{FALSE}).
 #'
 #' @family legislative district functions
 #' @export
@@ -224,7 +229,7 @@ state_legislative_districts <- function(state, house = "upper", cb = FALSE, year
 #' plot(ia)
 #'
 #' }
-voting_districts <- function(state) {
+voting_districts <- function(state, ...) {
 
   message("The voting districts shapefiles are from the 2012 TIGER/Line dataset.")
 
@@ -236,6 +241,8 @@ voting_districts <- function(state) {
                 state,
                 "_vtd10.zip")
 
-  return(load_tiger(url, tigris_type = 'voting_districts'))
+  return(load_tiger(url, tigris_type = 'voting_districts', ...))
 
 }
+
+
